/**
 * Interface representing a cache factory.
 */
export class CacheFactoryFactory {
    /**
     * Creates an cache based on the provided configuration.
     *
     * @param {TypeConfig} config - The configuration object for the cache provider.
     * @returns {Promise<CacheInterface>} - An cache provider instance.
     * @throws {Error} - Throws an error when requested provider cache can't be created.
     */
    async createCache(config) {
        if (!config.CACHE_TYPE) {
            throw new Error('The cache type is missing in the configuration	object.');
        }
        try {
            const cacheType = config.CACHE_TYPE;
            const packageName = '@cachehub/' + cacheType;
            // Dynamically import the package and access the default export
            // eslint-disable-next-line @typescript-eslint/naming-convention
            const ProviderModule = await import(packageName);
            // eslint-disable-next-line @typescript-eslint/naming-convention
            const Factory = ProviderModule.default;
            // we need to check if Factory has the createSender method, required by the EmailProviderFactoryInterface
            if (typeof Factory !== 'function' || !('createCache' in Factory.prototype)) {
                throw new Error('The module does not implement the required interface.');
            }
            // Instantiate the factory and create the sender
            return new Factory().createCache(config);
        }
        catch (error) {
            // Log the actual error for debugging
            console.error('Failed to create cache:', error);
            throw new Error(`Failed to create a cache for "${config.CACHE_TYPE || 'unknown'}".`);
        }
    }
}
