export interface CacheInterface {
    /**
     * Sets a value for a given key with an optional expiration time.
     * @param {string} key - The key under which to store the value.
     * @param {TypeValue} value - The value to store.
     * @param {number} [expiresAfter] - The time in seconds after which the entry should expire.
     * @returns {Promise<boolean>} - A promise that resolves to true if the value was set successfully, false otherwise.
     */
    set<TypeValue = string>(key: string, value: TypeValue, expiresAfter?: number): Promise<boolean>;
    /**
     * Retrieves a value from the cache by its key.
     * @param {string} key - The key of the entry to retrieve.
     * @returns {Promise<TypeValue | undefined>} - A promise that resolves to the value associated with the key, or undefined if not found.
     */
    get<TypeValue = string>(key: string): Promise<TypeValue | undefined>;
    /**
     * Deletes an entry with a given key.
     * @param {string} key - The key of the entry to delete.
     * @returns {Promise<boolean>} - A promise that resolves to true if the entry was deleted, false otherwise.
     */
    delete(key: string): Promise<boolean>;
    /**
     * Checks if a key exists in the cache.
     * @param {string} key - The key to check.
     * @returns {Promise<boolean>} - A promise that resolves to true if the key exists, false otherwise.
     */
    has(key: string): Promise<boolean>;
}
